# py-matrix-algorithms

Python library of 2-dimensional matrix algorithms.

## Algorithms

Available:

* [PCA](https://web.archive.org/web/20160630035830/http://statmaster.sdu.dk:80/courses/ST02/module05/module.pdf)
* [CCAFilter](http://citeseerx.ist.psu.edu/viewdoc/summary?doi=10.1.1.30.16)
* [GLSW](http://wiki.eigenvector.com/index.php?title=Advanced_Preprocessing:_Multivariate_Filtering#GLSW_Algorithm)
* [EPO](http://wiki.eigenvector.com/index.php?title=Advanced_Preprocessing:_Multivariate_Filtering#External_Parameter_Orthogonalization_.28EPO.29) (External Parameter Orthogonalization)
* [YGradientGLSW](http://wiki.eigenvector.com/index.php?title=Advanced_Preprocessing:_Multivariate_Filtering#GLSW_Algorithm)
* [YGradientEPO](http://wiki.eigenvector.com/index.php?title=Advanced_Preprocessing:_Multivariate_Filtering#External_Parameter_Orthogonalization_.28EPO.29)
* [FastICA](https://www.cs.helsinki.fi/u/ahyvarin/papers/bookfinal_ICA.pdf)
* [CCARegression]()
* [DIPLS](https://pubs.acs.org/doi/10.1021/acs.analchem.8b00498)
* [KernelPLS](http://www.plantbreeding.wzw.tum.de/fileadmin/w00bdb/www/kraemer/icml_kernelpls.pdf)
* [NIPALS](http://www.statsoft.com/textbook/partial-least-squares/#NIPALS)
* [OPLS](https://www.r-bloggers.com/evaluation-of-orthogonal-signal-correction-for-pls-modeling-osc-pls-and-opls/) (orthogonal signal correction)
* [PLS1](https://web.archive.org/web/20081001154431/http://statmaster.sdu.dk:80/courses/ST02/module07/module.pdf)
* [PRM]()
* [SIMPLS](http://www.statsoft.com/textbook/partial-least-squares/#SIMPLS)
* [SparsePLS](https://www.ncbi.nlm.nih.gov/pmc/articles/PMC2810828/)
* [VCPLS](http://or.nsfc.gov.cn/bitstream/00001903-5/485833/1/1000013952154.pdf)

Planned:

* [rPLS](https://www.researchgate.net/publication/259536250_Recursive_weighted_partial_least_squares_rPLS_An_efficient_variable_selection_method_using_PLS)
* [iPLS](https://www.researchgate.net/publication/247776629_Interval_Partial_Least-Squares_Regression_iPLS_A_Comparative_Chemometric_Study_with_an_Example_from_Near-Infrared_Spectroscopy)
* [PLS2](https://web.archive.org/web/20160702070233/http://statmaster.sdu.dk/courses/ST02/module08/module.pdf)
* [mwPLS]()
* [biPLS](https://www.academia.edu/14468430/Sequential_application_of_backward_interval_partial_least_squares_and_genetic_algorithms_for_the_selection_of_relevant_spectral_regions)

## Filters

* [Downsample]()

## Transformations

* [Center]()
* [MultiplicativeScatterCorrection]()
* [Passthrough]()
* [RowNorm]()
* [Savitzky-Golay]()
* [Savitzky-Golay 2]()
* [Standardize]()

## Installation

TODO


## Examples

TODO
